@@ -10,28 +10,42 @@ T = TypeVar("T", bound="ErrorMessage")
 @attr.s(auto_attribs=True)
 class ErrorMessage:
     """ """
-
+    code: Union[Unset, int] = UNSET
     message: Union[Unset, str] = UNSET
+    status: Union[Unset, str] = UNSET
+
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        code = self.code
         message = self.message
+        status = self.status
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
+        if code is not UNSET:
+            field_dict['code'] = code
         if message is not UNSET:
-            field_dict["message"] = message
+            field_dict['message'] = message
+        if status is not UNSET:
+            field_dict['status'] = status
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
+        code = d.pop("code", UNSET)
+
         message = d.pop("message", UNSET)
 
+        status = d.pop("status", UNSET)
+
         error_message = cls(
+            code=code,
             message=message,
+            status=status,
         )
 
         error_message.additional_properties = d
